Package: rapidsplithalf
Type: Package
Title: A Fast Permutation-Based Split-Half Reliability Algorithm
Version: 0.8
Authors@R: person("Sercan", "Kahveci", role = c("aut","cre"),email = "sercan.kahveci@plus.ac.at",comment=c(ORCID = "0000-0002-4139-5710"))
Description: Accurately estimates the reliability of cognitive tasks using a fast and flexible permutation-based split-half reliability algorithm that supports stratified splitting while maintaining equal split sizes. See Kahveci, Bathke, and Blechert (2025) <doi:10.3758/s13423-024-02597-y> for details.
License: GPL (>= 2)
BugReports: https://github.com/Spiritspeak/rapidsplit/issues/
Depends: R(>= 4.1.0)
Imports: Rcpp (>= 1.0.5), fastmatch, kit
Suggests: knitr, rmarkdown
LinkingTo: Rcpp
RoxygenNote: 7.3.3
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-07-15 14:43:27 UTC; b1066151
Author: Sercan Kahveci [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4139-5710>)
Maintainer: Sercan Kahveci <sercan.kahveci@plus.ac.at>
Repository: CRAN
Date/Publication: 2026-07-15 15:10:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-07-15 15:23:04 UTC; unix
Archs: rapidsplithalf.so.dSYM
