# Generated by roxygen2: do not edit by hand

S3method(plot,rapidsplit)
S3method(print,compcorr)
S3method(print,rapidsplit)
export(bootstrapWeights)
export(colMeansMasked)
export(colMedians)
export(colMediansMasked)
export(colProds)
export(colSds)
export(colSdsMasked)
export(compcorr)
export(comprel)
export(corByColumns)
export(corByColumns_mask)
export(corStatsByColumns)
export(cormean)
export(excludeOutliersByMask)
export(generateSplits)
export(loo.rapidsplit)
export(maskOutliers)
export(maskOutliersMasked)
export(meansByMask)
export(meansByWeight)
export(mediansByMask)
export(mediansByWeight)
export(r2p)
export(r2t)
export(r2z)
export(rapidsplit)
export(rapidsplit.chunks)
export(rconfint)
export(requiredTestSize)
export(sdsByMask)
export(sdsByWeight)
export(spearmanBrown)
export(stratifiedItersplits)
export(t2r)
export(z2r)
import(Rcpp)
importFrom(fastmatch,"%fin%")
importFrom(fastmatch,fmatch)
importFrom(grDevices,rgb)
importFrom(graphics,text)
importFrom(kit,countOccur)
importFrom(kit,funique)
importFrom(kit,uniqLen)
importFrom(stats,cor)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(rapidsplithalf)
